@@ -62,14 +62,18 @@ class FundManager:
         self.managed_fund = ManagedFund(self.manager_id)
         self.managed_fund_prize = ManagedFundPrize(self.manager_id)
         self.jiuquan_score = JiuquanScore(self.manager_id)
+        self.indicator = Indicator(self.manager_id)
 
     def __retrieve_fund_manager_raw_from_jiuquan(self):
+        logger.info(f'Retrieve fund manager for <{self.manager_id}>')
         # 分别从韭圈儿获取数据
         self.personal_detail.retrieve_data_from_jiuquan()
         self.total_stock_holding.retrieve_data_from_jiuquan()
         self.managed_fund.retrieve_data_from_jiuquan()
         self.jiuquan_score.retrieve_data_from_jiuquan(self.personal_detail.manager_tag_list)
         self.managed_fund_prize.retrieve_data_from_jiuquan()
+        self.indicator.retrieve_data_from_jiuquan(self.personal_detail.manager_name,
+                                                  self.personal_detail.manager_tag_list)
 
         dict_fund_manager_raw = dict()
         dict_fund_manager_raw['personal_detail'] = self.personal_detail.dict_raw
@@ -77,6 +81,7 @@ class FundManager:
         dict_fund_manager_raw['managed_fund'] = self.managed_fund.dict_raw
         dict_fund_manager_raw['jiuquan_score'] = self.jiuquan_score.dict_raw
         dict_fund_manager_raw['managed_fund_prize'] = self.managed_fund_prize.dict_raw
+        dict_fund_manager_raw['indicator'] = self.indicator.dict_raw
 
         return dict_fund_manager_raw
 
@@ -108,6 +113,7 @@ class FundManager:
         self.managed_fund.populate_item_raw_to_object(item_raw['managed_fund'])
         self.managed_fund_prize.populate_item_raw_to_object(item_raw['managed_fund_prize'])
         self.jiuquan_score.populate_item_raw_to_object(item_raw['jiuquan_score'])
+        self.indicator.populate_item_raw_to_object(item_raw['indicator'])
 
 
 class PersonalDetail:
@@ -161,6 +167,7 @@ class PersonalDetail:
         self.score = item_raw['mark']
         self.annual_return = item_raw['avgYearReturn1']
         self.df_ob_prize = pd.DataFrame(item_raw['ob_price'])
+        self.manager_tag_list = item_raw['line_tags']
 
 
 class TotalStockHolding:
@@ -332,3 +339,120 @@ class JiuquanScore:
                 item['data'].insert(0, item['name'])
                 df.loc[item_raw[key]['series'].index(item)] = item['data']
             self.dict_cate_score[key] = df
+
+
+class Indicator:
+    def __init__(self, manager_id: str):
+        self.draw_back = {}
+        self.dabaozha = {}
+        self.income = {}
+        self.dict_raw = {}
+        self.manager_id = manager_id
+
+    def retrieve_data_from_jiuquan(self, manager_name: str, manager_tag_list: list, benchmark: str = '000300.SH'):
+        for manager_tag in manager_tag_list:
+            self.dict_raw[manager_tag['name']] = {}
+            # 取经理曲线
+            personline_request_param = {
+                "id": self.manager_id,
+                "person_name": manager_name,
+                "category_name": manager_tag['name'],
+                "ben": benchmark,
+                "type": "pc",
+                "category": "dl",
+                # "data_source": "xichou",  # 字段不同基金不一样，暂时注释，好像不影响
+                "version": "1.8.9",
+                "authtoken": const.JIUQUAN_TOKEN,
+                "act_time": int(round(time.time() * 1000)),
+            }
+            personline_dict_raw = ut.request_post_json(
+                api_url='https://api.jiucaishuo.com/v2/personlists/personline',
+                headers=const.JIUQUAN_HEADER,
+                request_param=personline_request_param
+            )
+
+            # 取大爆炸曲线
+            dabaozha_request_param = {
+                "id": self.manager_id,
+                # "person_name": manager_name,
+                "category_name": manager_tag['name'],
+                "category_code": manager_tag['classify_code'],
+                "ben": benchmark,
+                "type": "pc",
+                "category": "dl",
+                # "data_source": "xichou",  # 字段不同基金不一样，暂时注释，好像不影响
+                "version": "1.8.9",
+                "authtoken": const.JIUQUAN_TOKEN,
+                "act_time": int(round(time.time() * 1000)),
+            }
+            dabaozha_dict_raw = ut.request_post_json(
+                api_url='https://api.jiucaishuo.com/v2/personlists/bigdata',
+                headers=const.JIUQUAN_HEADER,
+                request_param=dabaozha_request_param
+            )
+
+            # 取回撤数据
+            drawback_request_param = {
+                "id": self.manager_id,
+                # "person_name": manager_name,
+                "category_name": manager_tag['name'],
+                "category_code": manager_tag['classify_code'],
+                "ben": benchmark,
+                "type": "pc",
+                "category": "dl",
+                # "data_source": "xichou",  # 字段不同基金不一样，暂时注释，好像不影响
+                "version": "1.8.9",
+                "authtoken": const.JIUQUAN_TOKEN,
+                "act_time": int(round(time.time() * 1000)),
+            }
+            drawback_dict_raw = ut.request_post_json(
+                api_url='https://api.jiucaishuo.com/v2/personlists/personhcline',
+                headers=const.JIUQUAN_HEADER,
+                request_param=drawback_request_param
+            )
+            self.dict_raw[manager_tag['name']]['personline'] = personline_dict_raw
+            self.dict_raw[manager_tag['name']]['dabaozha'] = dabaozha_dict_raw
+            self.dict_raw[manager_tag['name']]['drawback'] = drawback_dict_raw
+
+    def populate_item_raw_to_object(self, item_raw):
+        for key in item_raw.keys():
+            income_line_data_df = pd.DataFrame()
+            for item_data in item_raw[key]['personline']['series']:
+                temp_df = pd.DataFrame(
+                    item_data["data"], columns=["日期", item_data['name']]
+                )
+                temp_df["日期"] = pd.to_datetime(temp_df["日期"], unit="ms", utc=True).dt.tz_convert(
+                    "Asia/Shanghai").dt.date
+                temp_df["日期"] = temp_df["日期"].apply(lambda x: x.strftime('%Y%m%d'))
+                temp_df.set_index(["日期"], inplace=True)
+                income_line_data_df = pd.concat([income_line_data_df, temp_df], axis=1)
+            income_line_data_df.sort_index(inplace=True)
+            self.income[key] = income_line_data_df
+
+            dabaozha_line_data_df = pd.DataFrame()
+            for item_data in item_raw[key]['dabaozha']['series'].values():
+                temp_df = pd.DataFrame(
+                    item_data["data"], columns=["日期", item_data['name']]
+                )
+                temp_df["日期"] = pd.to_datetime(temp_df["日期"], unit="ms", utc=True).dt.tz_convert(
+                    "Asia/Shanghai").dt.date
+                temp_df["日期"] = temp_df["日期"].apply(lambda x: x.strftime('%Y%m%d'))
+                temp_df.set_index(["日期"], inplace=True)
+                dabaozha_line_data_df = dabaozha_line_data_df.loc[~dabaozha_line_data_df.index.duplicated(keep='first')]
+                temp_df = temp_df.loc[~temp_df.index.duplicated(keep='first')]
+                dabaozha_line_data_df = pd.concat([dabaozha_line_data_df, temp_df], axis=1)
+            dabaozha_line_data_df.sort_index(inplace=True)
+            self.dabaozha[key] = dabaozha_line_data_df
+
+            draw_back_line_data_df = pd.DataFrame()
+            for item_data in item_raw[key]['drawback']['hc_series']:
+                temp_df = pd.DataFrame(
+                    item_data["data"], columns=["日期", item_data['name']]
+                )
+                temp_df["日期"] = pd.to_datetime(temp_df["日期"], unit="ms", utc=True).dt.tz_convert(
+                    "Asia/Shanghai").dt.date
+                temp_df["日期"] = temp_df["日期"].apply(lambda x: x.strftime('%Y%m%d'))
+                temp_df.set_index(["日期"], inplace=True)
+                draw_back_line_data_df = pd.concat([draw_back_line_data_df, temp_df], axis=1)
+            draw_back_line_data_df.sort_index(inplace=True)
+            self.draw_back[key] = draw_back_line_data_df
