@@ -9,8 +9,10 @@ class TestFundRankList(TestCase):
         self.fund_rank_list_object = FundRankList(
             type_name='收益率排名',
             cate_l1='行业赛道',
-            cate_l2='医药生物'
+            cate_l2='医药生物',
+            retrieve_type_cate_md=False
         )
+        print()
 
     def test_format_rank_list(self):
         result2 = ut.get_numeric_df_by_column(
